Multiple accounts
=======================

Sometimes you have multiple accounts for the same site. In this case you can manage the accounts with separate site names, but you may want to manage it with a single site name.

In this situation, you can share the sitekey and produce separate passwords for separate accounts by changing the master password. For example, you use your regular master password for your main account and you add specific word to your master password in your second account. The changing rule can be stored in comment together with the account information.

This method is also useful when you have accounts for similar sites, such as amazon.com and amazon.co.jp.

----

Toppage_

.. _Toppage: README.rst
